==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/features/kotlin/enums/SubscriptionFeatureRegistrationState.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.features.kotlin.enums

import com.pulumi.kotlin.ConvertibleToJava
import kotlin.Suppress

/**
 * The state.
 */
public enum class SubscriptionFeatureRegistrationState(
    public val javaValue: com.pulumi.azurenative.features.enums.SubscriptionFeatureRegistrationState,
) : ConvertibleToJava<com.pulumi.azurenative.features.enums.SubscriptionFeatureRegistrationState> {
    NotSpecified(com.pulumi.azurenative.features.enums.SubscriptionFeatureRegistrationState.NotSpecified),
    NotRegistered(com.pulumi.azurenative.features.enums.SubscriptionFeatureRegistrationState.NotRegistered),
    Pending(com.pulumi.azurenative.features.enums.SubscriptionFeatureRegistrationState.Pending),
    Registering(com.pulumi.azurenative.features.enums.SubscriptionFeatureRegistrationState.Registering),
    Registered(com.pulumi.azurenative.features.enums.SubscriptionFeatureRegistrationState.Registered),
    Unregistering(com.pulumi.azurenative.features.enums.SubscriptionFeatureRegistrationState.Unregistering),
    Unregistered(com.pulumi.azurenative.features.enums.SubscriptionFeatureRegistrationState.Unregistered),
    ;

    override fun toJava(): com.pulumi.azurenative.features.enums.SubscriptionFeatureRegistrationState =
        javaValue

    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.features.enums.SubscriptionFeatureRegistrationState):
            SubscriptionFeatureRegistrationState =
            SubscriptionFeatureRegistrationState.values().first { it.javaValue == javaType }
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/features/kotlin/enums/SubscriptionFeatureRegistrationState.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.features.kotlin.enums

import com.pulumi.kotlin.ConvertibleToJava
import kotlin.Suppress

/**
 * The state.
 */
public enum class SubscriptionFeatureRegistrationState(
    public val javaValue: com.pulumi.azurenative.features.enums.SubscriptionFeatureRegistrationState,
) : ConvertibleToJava<com.pulumi.azurenative.features.enums.SubscriptionFeatureRegistrationState> {
    NotSpecified(com.pulumi.azurenative.features.enums.SubscriptionFeatureRegistrationState.NotSpecified),
    NotRegistered(com.pulumi.azurenative.features.enums.SubscriptionFeatureRegistrationState.NotRegistered),
    Pending(com.pulumi.azurenative.features.enums.SubscriptionFeatureRegistrationState.Pending),
    Registering(com.pulumi.azurenative.features.enums.SubscriptionFeatureRegistrationState.Registering),
    Registered(com.pulumi.azurenative.features.enums.SubscriptionFeatureRegistrationState.Registered),
    Unregistering(com.pulumi.azurenative.features.enums.SubscriptionFeatureRegistrationState.Unregistering),
    Unregistered(com.pulumi.azurenative.features.enums.SubscriptionFeatureRegistrationState.Unregistered),
    ;

    override fun toJava(): com.pulumi.azurenative.features.enums.SubscriptionFeatureRegistrationState = javaValue

    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.features.enums.SubscriptionFeatureRegistrationState): SubscriptionFeatureRegistrationState =
            SubscriptionFeatureRegistrationState.values().first { it.javaValue == javaType }
    }
}
